@@ -1,7 +1,7 @@
 #include "fitz.h"
 
 fz_buffer *
-fz_newbuffer(int size)
+fz_new_buffer(int size)
 {
 	fz_buffer *b;
 
@@ -17,14 +17,14 @@ fz_newbuffer(int size)
 }
 
 fz_buffer *
-fz_keepbuffer(fz_buffer *buf)
+fz_keep_buffer(fz_buffer *buf)
 {
 	buf->refs ++;
 	return buf;
 }
 
 void
-fz_dropbuffer(fz_buffer *buf)
+fz_drop_buffer(fz_buffer *buf)
 {
 	if (--buf->refs == 0)
 	{
@@ -34,7 +34,7 @@ fz_dropbuffer(fz_buffer *buf)
 }
 
 void
-fz_resizebuffer(fz_buffer *buf, int size)
+fz_resize_buffer(fz_buffer *buf, int size)
 {
 	buf->data = fz_realloc(buf->data, size, 1);
 	buf->cap = size;
@@ -43,7 +43,7 @@ fz_resizebuffer(fz_buffer *buf, int size)
 }
 
 void
-fz_growbuffer(fz_buffer *buf)
+fz_grow_buffer(fz_buffer *buf)
 {
-	fz_resizebuffer(buf, (buf->cap * 3) / 2);
+	fz_resize_buffer(buf, (buf->cap * 3) / 2);
 }
